@@ -16,28 +16,28 @@ class PortalUserTrait(object):
                 username=request_data['username'],
                 password=request_data['password']
             )
-        return api_common({})
+        return api_common(code=-1,  data={})
 
     @staticmethod
     def user_login(request):
-        checked, app_client, request_data = AuthTrait.portal_auth_check(request)
+        checked, app_client, request_data = AuthTrait.portal_auth_check(request=request, need_auth=False)
         if checked:
             return app_client.user_login(
                 username=request_data['username'],
                 password=request_data['password']
             )
-        return api_common({})
+        return api_common(code=-1,  data={})
 
     @staticmethod
     def user_logout(request):
         checked, app_client, request_data = AuthTrait.portal_auth_check(request)
         if checked:
             return app_client.user_logout(request.headers['X-Token'])
-        return api_common({})
+        return api_common(code=-1,  data={})
 
     @staticmethod
     def user_info(request):
         checked, app_client, request_data = AuthTrait.portal_auth_check(request)
         if checked:
             return app_client.user_info(request.headers['X-Token'])
-        return api_common({})
+        return api_common(code=-1,  data={})
