@@ -1,25 +1,25 @@
-from passport.core.paginator_tools import paginator
-from passport.core.views import api_common
-from passport.model.permission_manager import PermissionManager
-from passport.model.role_manager import RoleManager
 from passport.model.token_manager import TokenManager
+
 from app import app_client
 
 
 class AuthTrait(object):
 
     @staticmethod
-    def portal_auth_check(request):
+    def portal_auth_check(request, need_auth=True):
         """
         认证检查
         :param request:
         :return:
         """
-        if 'X-Token' in request.headers:
-            if app_client and app_client.get_access_token():
-                request_data = request.get_json(silent=True)
+        request_data = request.get_json(silent=True)
+        if app_client and app_client.get_access_token():
+            if need_auth:
+                if 'X-Token' in request.headers:
+                    return True, app_client, request_data
+            else:
                 return True, app_client, request_data
-        return False, app_client, None
+        return False, app_client, request_data
 
     @staticmethod
     def auth_check(request):
